@@ -3,7 +3,7 @@ package Apache::Session::Store::MongoDB;
 use 5.010;
 use strict;
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 use MongoDB;
 
@@ -25,7 +25,12 @@ sub connection {
       if ( defined $self->{collection} );
     my $conn_args;
     foreach my $w (
-        qw(auth_mechanism auth_mechanism_properties connect_timeout_ms ssl username password)
+        qw(host auth_mechanism auth_mechanism_properties bson_codec
+        connect_timeout_ms db_name heartbeat_frequency_ms j local_threshold_ms
+        max_time_ms password port read_pref_mode read_pref_tag_sets
+        replica_set_name server_selection_timeout_ms server_selection_try_once
+        socket_check_interval_ms socket_timeout_ms ssl username w wtimeout
+        read_concern_level)
       )
     {
         $conn_args->{$w} = $session->{args}->{$w} || $default->{$w};
@@ -110,7 +115,7 @@ Xavier Guimard, E<lt>x.guimard@free.frE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2015 by Xavier Guimard, E<lt>x.guimard@free.frE<gt>
+Copyright (C) 2015-2016 by Xavier Guimard, E<lt>x.guimard@free.frE<gt>
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.10.0 or,
